==> we-node-client-grpc-java-0.3.0-sources.jar: com/wavesenterprise/protobuf/service/messagebroker/BlockchainEventsServiceGrpc.java <==
package com.wavesenterprise.protobuf.service.messagebroker;

import static io.grpc.MethodDescriptor.generateFullMethodName;
import static io.grpc.stub.ClientCalls.asyncBidiStreamingCall;
import static io.grpc.stub.ClientCalls.asyncClientStreamingCall;
import static io.grpc.stub.ClientCalls.asyncServerStreamingCall;
import static io.grpc.stub.ClientCalls.asyncUnaryCall;
import static io.grpc.stub.ClientCalls.blockingServerStreamingCall;
import static io.grpc.stub.ClientCalls.blockingUnaryCall;
import static io.grpc.stub.ClientCalls.futureUnaryCall;
import static io.grpc.stub.ServerCalls.asyncBidiStreamingCall;
import static io.grpc.stub.ServerCalls.asyncClientStreamingCall;
import static io.grpc.stub.ServerCalls.asyncServerStreamingCall;
import static io.grpc.stub.ServerCalls.asyncUnaryCall;
import static io.grpc.stub.ServerCalls.asyncUnimplementedStreamingCall;
import static io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.16.0)",
    comments = "Source: messagebroker/messagebroker_blockchain_events_service.proto")
public final class BlockchainEventsServiceGrpc {

  private BlockchainEventsServiceGrpc() {}

  public static final String SERVICE_NAME = "wavesenterprise.BlockchainEventsService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest,
      com.wavesenterprise.protobuf.service.messagebroker.MessagebrokerBlockchainEvent.BlockchainEvent> getSubscribeOnMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "SubscribeOn",
      requestType = com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest.class,
      responseType = com.wavesenterprise.protobuf.service.messagebroker.MessagebrokerBlockchainEvent.BlockchainEvent.class,
      methodType = io.grpc.MethodDescriptor.MethodType.SERVER_STREAMING)
  public static io.grpc.MethodDescriptor<com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest,
      com.wavesenterprise.protobuf.service.messagebroker.MessagebrokerBlockchainEvent.BlockchainEvent> getSubscribeOnMethod() {
    io.grpc.MethodDescriptor<com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest, com.wavesenterprise.protobuf.service.messagebroker.MessagebrokerBlockchainEvent.BlockchainEvent> getSubscribeOnMethod;
    if ((getSubscribeOnMethod = BlockchainEventsServiceGrpc.getSubscribeOnMethod) == null) {
      synchronized (BlockchainEventsServiceGrpc.class) {
        if ((getSubscribeOnMethod = BlockchainEventsServiceGrpc.getSubscribeOnMethod) == null) {
          BlockchainEventsServiceGrpc.getSubscribeOnMethod = getSubscribeOnMethod = 
              io.grpc.MethodDescriptor.<com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest, com.wavesenterprise.protobuf.service.messagebroker.MessagebrokerBlockchainEvent.BlockchainEvent>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.SERVER_STREAMING)
              .setFullMethodName(generateFullMethodName(
                  "wavesenterprise.BlockchainEventsService", "SubscribeOn"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.wavesenterprise.protobuf.service.messagebroker.MessagebrokerBlockchainEvent.BlockchainEvent.getDefaultInstance()))
                  .setSchemaDescriptor(new BlockchainEventsServiceMethodDescriptorSupplier("SubscribeOn"))
                  .build();
          }
        }
     }
     return getSubscribeOnMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static BlockchainEventsServiceStub newStub(io.grpc.Channel channel) {
    return new BlockchainEventsServiceStub(channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static BlockchainEventsServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    return new BlockchainEventsServiceBlockingStub(channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static BlockchainEventsServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    return new BlockchainEventsServiceFutureStub(channel);
  }

  /**
   */
  public static abstract class BlockchainEventsServiceImplBase implements io.grpc.BindableService {

    /**
     */
    public void subscribeOn(com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest request,
        io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.messagebroker.MessagebrokerBlockchainEvent.BlockchainEvent> responseObserver) {
      asyncUnimplementedUnaryCall(getSubscribeOnMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getSubscribeOnMethod(),
            asyncServerStreamingCall(
              new MethodHandlers<
                com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest,
                com.wavesenterprise.protobuf.service.messagebroker.MessagebrokerBlockchainEvent.BlockchainEvent>(
                  this, METHODID_SUBSCRIBE_ON)))
          .build();
    }
  }

  /**
   */
  public static final class BlockchainEventsServiceStub extends io.grpc.stub.AbstractStub<BlockchainEventsServiceStub> {
    private BlockchainEventsServiceStub(io.grpc.Channel channel) {
      super(channel);
    }

    private BlockchainEventsServiceStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected BlockchainEventsServiceStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new BlockchainEventsServiceStub(channel, callOptions);
    }

    /**
     */
    public void subscribeOn(com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest request,
        io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.messagebroker.MessagebrokerBlockchainEvent.BlockchainEvent> responseObserver) {
      asyncServerStreamingCall(
          getChannel().newCall(getSubscribeOnMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   */
  public static final class BlockchainEventsServiceBlockingStub extends io.grpc.stub.AbstractStub<BlockchainEventsServiceBlockingStub> {
    private BlockchainEventsServiceBlockingStub(io.grpc.Channel channel) {
      super(channel);
    }

    private BlockchainEventsServiceBlockingStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected BlockchainEventsServiceBlockingStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new BlockchainEventsServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public java.util.Iterator<com.wavesenterprise.protobuf.service.messagebroker.MessagebrokerBlockchainEvent.BlockchainEvent> subscribeOn(
        com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest request) {
      return blockingServerStreamingCall(
          getChannel(), getSubscribeOnMethod(), getCallOptions(), request);
    }
  }

  /**
   */
  public static final class BlockchainEventsServiceFutureStub extends io.grpc.stub.AbstractStub<BlockchainEventsServiceFutureStub> {
    private BlockchainEventsServiceFutureStub(io.grpc.Channel channel) {
      super(channel);
    }

    private BlockchainEventsServiceFutureStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected BlockchainEventsServiceFutureStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new BlockchainEventsServiceFutureStub(channel, callOptions);
    }
  }

  private static final int METHODID_SUBSCRIBE_ON = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final BlockchainEventsServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(BlockchainEventsServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_SUBSCRIBE_ON:
          serviceImpl.subscribeOn((com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest) request,
              (io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.messagebroker.MessagebrokerBlockchainEvent.BlockchainEvent>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class BlockchainEventsServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    BlockchainEventsServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return com.wavesenterprise.protobuf.service.messagebroker.MessagebrokerBlockchainEventsService.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("BlockchainEventsService");
    }
  }

  private static final class BlockchainEventsServiceFileDescriptorSupplier
      extends BlockchainEventsServiceBaseDescriptorSupplier {
    BlockchainEventsServiceFileDescriptorSupplier() {}
  }

  private static final class BlockchainEventsServiceMethodDescriptorSupplier
      extends BlockchainEventsServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    BlockchainEventsServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (BlockchainEventsServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new BlockchainEventsServiceFileDescriptorSupplier())
              .addMethod(getSubscribeOnMethod())
              .build();
        }
      }
    }
    return result;
  }
}

==> we-node-client-grpc-java-2.0.0-sources.jar: com/wavesenterprise/protobuf/service/messagebroker/BlockchainEventsServiceGrpc.java <==
package com.wavesenterprise.protobuf.service.messagebroker;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.64.0)",
    comments = "Source: messagebroker/messagebroker_blockchain_events_service.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class BlockchainEventsServiceGrpc {

  private BlockchainEventsServiceGrpc() {}

  public static final java.lang.String SERVICE_NAME = "wavesenterprise.BlockchainEventsService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest,
      com.wavesenterprise.protobuf.service.messagebroker.MessagebrokerBlockchainEvent.BlockchainEvent> getSubscribeOnMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "SubscribeOn",
      requestType = com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest.class,
      responseType = com.wavesenterprise.protobuf.service.messagebroker.MessagebrokerBlockchainEvent.BlockchainEvent.class,
      methodType = io.grpc.MethodDescriptor.MethodType.SERVER_STREAMING)
  public static io.grpc.MethodDescriptor<com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest,
      com.wavesenterprise.protobuf.service.messagebroker.MessagebrokerBlockchainEvent.BlockchainEvent> getSubscribeOnMethod() {
    io.grpc.MethodDescriptor<com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest, com.wavesenterprise.protobuf.service.messagebroker.MessagebrokerBlockchainEvent.BlockchainEvent> getSubscribeOnMethod;
    if ((getSubscribeOnMethod = BlockchainEventsServiceGrpc.getSubscribeOnMethod) == null) {
      synchronized (BlockchainEventsServiceGrpc.class) {
        if ((getSubscribeOnMethod = BlockchainEventsServiceGrpc.getSubscribeOnMethod) == null) {
          BlockchainEventsServiceGrpc.getSubscribeOnMethod = getSubscribeOnMethod =
              io.grpc.MethodDescriptor.<com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest, com.wavesenterprise.protobuf.service.messagebroker.MessagebrokerBlockchainEvent.BlockchainEvent>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.SERVER_STREAMING)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "SubscribeOn"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.wavesenterprise.protobuf.service.messagebroker.MessagebrokerBlockchainEvent.BlockchainEvent.getDefaultInstance()))
              .setSchemaDescriptor(new BlockchainEventsServiceMethodDescriptorSupplier("SubscribeOn"))
              .build();
        }
      }
    }
    return getSubscribeOnMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static BlockchainEventsServiceStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<BlockchainEventsServiceStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<BlockchainEventsServiceStub>() {
        @java.lang.Override
        public BlockchainEventsServiceStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new BlockchainEventsServiceStub(channel, callOptions);
        }
      };
    return BlockchainEventsServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static BlockchainEventsServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<BlockchainEventsServiceBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<BlockchainEventsServiceBlockingStub>() {
        @java.lang.Override
        public BlockchainEventsServiceBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new BlockchainEventsServiceBlockingStub(channel, callOptions);
        }
      };
    return BlockchainEventsServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static BlockchainEventsServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<BlockchainEventsServiceFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<BlockchainEventsServiceFutureStub>() {
        @java.lang.Override
        public BlockchainEventsServiceFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new BlockchainEventsServiceFutureStub(channel, callOptions);
        }
      };
    return BlockchainEventsServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public interface AsyncService {

    /**
     */
    default void subscribeOn(com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest request,
        io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.messagebroker.MessagebrokerBlockchainEvent.BlockchainEvent> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getSubscribeOnMethod(), responseObserver);
    }
  }

  /**
   * Base class for the server implementation of the service BlockchainEventsService.
   */
  public static abstract class BlockchainEventsServiceImplBase
      implements io.grpc.BindableService, AsyncService {

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return BlockchainEventsServiceGrpc.bindService(this);
    }
  }

  /**
   * A stub to allow clients to do asynchronous rpc calls to service BlockchainEventsService.
   */
  public static final class BlockchainEventsServiceStub
      extends io.grpc.stub.AbstractAsyncStub<BlockchainEventsServiceStub> {
    private BlockchainEventsServiceStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected BlockchainEventsServiceStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new BlockchainEventsServiceStub(channel, callOptions);
    }

    /**
     */
    public void subscribeOn(com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest request,
        io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.messagebroker.MessagebrokerBlockchainEvent.BlockchainEvent> responseObserver) {
      io.grpc.stub.ClientCalls.asyncServerStreamingCall(
          getChannel().newCall(getSubscribeOnMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   * A stub to allow clients to do synchronous rpc calls to service BlockchainEventsService.
   */
  public static final class BlockchainEventsServiceBlockingStub
      extends io.grpc.stub.AbstractBlockingStub<BlockchainEventsServiceBlockingStub> {
    private BlockchainEventsServiceBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected BlockchainEventsServiceBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new BlockchainEventsServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public java.util.Iterator<com.wavesenterprise.protobuf.service.messagebroker.MessagebrokerBlockchainEvent.BlockchainEvent> subscribeOn(
        com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest request) {
      return io.grpc.stub.ClientCalls.blockingServerStreamingCall(
          getChannel(), getSubscribeOnMethod(), getCallOptions(), request);
    }
  }

  /**
   * A stub to allow clients to do ListenableFuture-style rpc calls to service BlockchainEventsService.
   */
  public static final class BlockchainEventsServiceFutureStub
      extends io.grpc.stub.AbstractFutureStub<BlockchainEventsServiceFutureStub> {
    private BlockchainEventsServiceFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected BlockchainEventsServiceFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new BlockchainEventsServiceFutureStub(channel, callOptions);
    }
  }

  private static final int METHODID_SUBSCRIBE_ON = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final AsyncService serviceImpl;
    private final int methodId;

    MethodHandlers(AsyncService serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_SUBSCRIBE_ON:
          serviceImpl.subscribeOn((com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest) request,
              (io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.messagebroker.MessagebrokerBlockchainEvent.BlockchainEvent>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  public static final io.grpc.ServerServiceDefinition bindService(AsyncService service) {
    return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
        .addMethod(
          getSubscribeOnMethod(),
          io.grpc.stub.ServerCalls.asyncServerStreamingCall(
            new MethodHandlers<
              com.wavesenterprise.protobuf.service.util.events.UtilEventsSubscribeOnRequest.SubscribeOnRequest,
              com.wavesenterprise.protobuf.service.messagebroker.MessagebrokerBlockchainEvent.BlockchainEvent>(
                service, METHODID_SUBSCRIBE_ON)))
        .build();
  }

  private static abstract class BlockchainEventsServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    BlockchainEventsServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return com.wavesenterprise.protobuf.service.messagebroker.MessagebrokerBlockchainEventsService.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("BlockchainEventsService");
    }
  }

  private static final class BlockchainEventsServiceFileDescriptorSupplier
      extends BlockchainEventsServiceBaseDescriptorSupplier {
    BlockchainEventsServiceFileDescriptorSupplier() {}
  }

  private static final class BlockchainEventsServiceMethodDescriptorSupplier
      extends BlockchainEventsServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final java.lang.String methodName;

    BlockchainEventsServiceMethodDescriptorSupplier(java.lang.String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (BlockchainEventsServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new BlockchainEventsServiceFileDescriptorSupplier())
              .addMethod(getSubscribeOnMethod())
              .build();
        }
      }
    }
    return result;
  }
}
